==> libuta-0.3.38.tgz: include/uta/uta.h <==

/*
  libuta - a C++ widget library based on SDL (Simple Direct Layer)
  Copyright (C) 1999  Karsten Laux

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.
  
  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.
  
  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA  02111-1307, SA.
*/

#include <uta/application.h>
#include <uta/button.h>
#include <uta/color.h>
#include <uta/debug.h>
#include <uta/dialog.h>
#include <uta/directsurface.h>
#include <uta/event.h>
#include <uta/font.h>
#include <uta/keysym.h>
#include <uta/label.h>
#include <uta/lineedit.h>
#include <uta/listbox.h>
#include <uta/logo.h>
#include <uta/mixer.h>
#include <uta/mouse.h>
#include <uta/movie.h>
#include <uta/multilineedit.h>
#include <uta/music.h>
#include <uta/mutex.h>
#include <uta/painter.h>
#include <uta/pixelformat.h>
#include <uta/point.h>
#include <uta/progressdialog.h>
#include <uta/pushbutton.h>
#include <uta/rect.h>
#include <uta/resources.h>
#include <uta/rootwindow.h>
#include <uta/sample.h>
#include <uta/screensurface.h>
#include <uta/shared.h>
#include <uta/sound.h>
#include <uta/soundmapper.h>
#include <uta/surface.h>
#include <uta/terminal.h>
#include <uta/togglebutton.h>
#include <uta/version.h>
#include <uta/widget.h>
#include <uta/timer.h>

==> libuta-0.4.4p5.tgz: include/uta/uta.h <==

/*
  libuta - a C++ widget library based on SDL (Simple Direct Layer)
  Copyright (C) 1999-2002  Karsten Laux

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.
  
  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.
  
  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the
  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA  02111-1307, SA.
*/

#include <uta/application.h>
#include <uta/button.h>
#include <uta/color.h>
#include <uta/debug.h>
#include <uta/dialog.h>
#include <uta/directsurface.h>
#include <uta/event.h>
#include <uta/font.h>
#include <uta/keysym.h>
#include <uta/label.h>
#include <uta/lineedit.h>
#include <uta/listbox.h>
#include <uta/logo.h>
#include <uta/mixer.h>
#include <uta/mouse.h>
#include <uta/movie.h>
#include <uta/multilineedit.h>
#include <uta/music.h>
#include <uta/mutex.h>
#include <uta/painter.h>
#include <uta/pixelformat.h>
#include <uta/point.h>
#include <uta/progressdialog.h>
#include <uta/pushbutton.h>
#include <uta/rect.h>
#include <uta/resources.h>
#include <uta/rootwindow.h>
#include <uta/sample.h>
#include <uta/screensurface.h>
#include <uta/shared.h>
#include <uta/sound.h>
#include <uta/soundmapper.h>
#include <uta/surface.h>
#include <uta/terminal.h>
#include <uta/togglebutton.h>
#include <uta/version.h>
#include <uta/widget.h>
#include <uta/timer.h>
